tlslite.integration.ClientHelper

Package tlslite :: Package integration :: Module ClientHelper |
[show private | hide private]
[frames | no frames]

## Module tlslite.integration.ClientHelper

A helper class for using TLS Lite with stdlib clients (httplib, xmlrpclib, imaplib, poplib).

Classes
`ClientHelper` | This is a helper class used to integrate TLS Lite with various TLS clients (e.g.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net